==> lasso_0.6.5.orig.tar.gz: lasso-0.6.5/swig/saml-2.0/main.h <==
%{
#include <lasso/xml/saml-2.0/samlp2_name_id_policy.h>
#include <lasso/xml/saml-2.0/samlp2_requested_authn_context.h>
#include <lasso/xml/saml-2.0/saml2_assertion.h>
#include <lasso/xml/saml-2.0/samlp2_idp_list.h>
#include <lasso/xml/saml-2.0/saml2_key_info_confirmation_data.h>
#include <lasso/xml/saml-2.0/saml2_conditions.h>
#include <lasso/xml/saml-2.0/saml2_evidence.h>
#include <lasso/xml/saml-2.0/saml2_name_id.h>
#include <lasso/xml/saml-2.0/samlp2_status_code.h>
#include <lasso/xml/saml-2.0/samlp2_status.h>
#include <lasso/xml/saml-2.0/saml2_condition_abstract.h>
#include <lasso/xml/saml-2.0/saml2_one_time_use.h>
#include <lasso/xml/saml-2.0/saml2_advice.h>
#include <lasso/xml/saml-2.0/saml2_base_idabstract.h>
#include <lasso/xml/saml-2.0/saml2_authn_context.h>
#include <lasso/xml/saml-2.0/saml2_subject_locality.h>
#include <lasso/xml/saml-2.0/saml2_subject_confirmation_data.h>
#include <lasso/xml/saml-2.0/saml2_subject_confirmation.h>
#include <lasso/xml/saml-2.0/saml2_proxy_restriction.h>
#include <lasso/xml/saml-2.0/saml2_statement_abstract.h>
#include <lasso/xml/saml-2.0/saml2_authn_statement.h>
#include <lasso/xml/saml-2.0/saml2_attribute_statement.h>
#include <lasso/xml/saml-2.0/samlp2_idp_entry.h>
#include <lasso/xml/saml-2.0/samlp2_extensions.h>
#include <lasso/xml/saml-2.0/saml2_action.h>
#include <lasso/xml/saml-2.0/samlp2_status_response.h>
#include <lasso/xml/saml-2.0/samlp2_response.h>
#include <lasso/xml/saml-2.0/samlp2_artifact_response.h>
#include <lasso/xml/saml-2.0/samlp2_request_abstract.h>
#include <lasso/xml/saml-2.0/samlp2_assertion_idrequest.h>
#include <lasso/xml/saml-2.0/samlp2_artifact_resolve.h>
#include <lasso/xml/saml-2.0/samlp2_name_id_mapping_request.h>
#include <lasso/xml/saml-2.0/samlp2_authn_request.h>
#include <lasso/xml/saml-2.0/samlp2_subject_query_abstract.h>
#include <lasso/xml/saml-2.0/samlp2_authz_decision_query.h>
#include <lasso/xml/saml-2.0/samlp2_attribute_query.h>
#include <lasso/xml/saml-2.0/saml2_audience_restriction.h>
#include <lasso/xml/saml-2.0/samlp2_logout_request.h>
#include <lasso/xml/saml-2.0/samlp2_authn_query.h>
#include <lasso/xml/saml-2.0/saml2_attribute.h>
#include <lasso/xml/saml-2.0/samlp2_terminate.h>
#include <lasso/xml/saml-2.0/samlp2_status_detail.h>
#include <lasso/xml/saml-2.0/saml2_authz_decision_statement.h>
#include <lasso/xml/saml-2.0/samlp2_name_id_mapping_response.h>
#include <lasso/xml/saml-2.0/saml2_encrypted_element.h>
#include <lasso/xml/saml-2.0/samlp2_manage_name_id_request.h>
#include <lasso/xml/saml-2.0/samlp2_scoping.h>
#include <lasso/xml/saml-2.0/saml2_subject.h>
%}
%include samlp2_name_id_policy.i
%include samlp2_requested_authn_context.i
%include saml2_assertion.i
%include samlp2_idp_list.i
%include saml2_key_info_confirmation_data.i
%include saml2_conditions.i
%include saml2_evidence.i
%include saml2_name_id.i
%include samlp2_status_code.i
%include samlp2_status.i
%include saml2_condition_abstract.i
%include saml2_one_time_use.i
%include saml2_advice.i
%include saml2_base_idabstract.i
%include saml2_authn_context.i
%include saml2_subject_locality.i
%include saml2_subject_confirmation_data.i
%include saml2_subject_confirmation.i
%include saml2_proxy_restriction.i
%include saml2_statement_abstract.i
%include saml2_authn_statement.i
%include saml2_attribute_statement.i
%include samlp2_idp_entry.i
%include samlp2_extensions.i
%include saml2_action.i
%include samlp2_status_response.i
%include samlp2_response.i
%include samlp2_artifact_response.i
%include samlp2_request_abstract.i
%include samlp2_assertion_idrequest.i
%include samlp2_artifact_resolve.i
%include samlp2_name_id_mapping_request.i
%include samlp2_authn_request.i
%include samlp2_subject_query_abstract.i
%include samlp2_authz_decision_query.i
%include samlp2_attribute_query.i
%include saml2_audience_restriction.i
%include samlp2_logout_request.i
%include samlp2_authn_query.i
%include saml2_attribute.i
%include samlp2_terminate.i
%include samlp2_status_detail.i
%include saml2_authz_decision_statement.i
%include samlp2_name_id_mapping_response.i
%include saml2_encrypted_element.i
%include samlp2_manage_name_id_request.i
%include samlp2_scoping.i
%include saml2_subject.i

==> lasso_2.2.0.orig.tar.gz: lasso-2.2.0/swig/saml-2.0/main.h <==
%{
#include <lasso/xml/saml-2.0/samlp2_name_id_policy.h>
#include <lasso/xml/saml-2.0/samlp2_requested_authn_context.h>
#include <lasso/xml/saml-2.0/saml2_assertion.h>
#include <lasso/xml/saml-2.0/samlp2_idp_list.h>
#include <lasso/xml/saml-2.0/saml2_key_info_confirmation_data.h>
#include <lasso/xml/saml-2.0/saml2_conditions.h>
#include <lasso/xml/saml-2.0/saml2_evidence.h>
#include <lasso/xml/saml-2.0/saml2_name_id.h>
#include <lasso/xml/saml-2.0/samlp2_status_code.h>
#include <lasso/xml/saml-2.0/samlp2_status.h>
#include <lasso/xml/saml-2.0/saml2_condition_abstract.h>
#include <lasso/xml/saml-2.0/saml2_one_time_use.h>
#include <lasso/xml/saml-2.0/saml2_advice.h>
#include <lasso/xml/saml-2.0/saml2_base_idabstract.h>
#include <lasso/xml/saml-2.0/saml2_authn_context.h>
#include <lasso/xml/saml-2.0/saml2_subject_locality.h>
#include <lasso/xml/saml-2.0/saml2_subject_confirmation_data.h>
#include <lasso/xml/saml-2.0/saml2_subject_confirmation.h>
#include <lasso/xml/saml-2.0/saml2_proxy_restriction.h>
#include <lasso/xml/saml-2.0/saml2_statement_abstract.h>
#include <lasso/xml/saml-2.0/saml2_authn_statement.h>
#include <lasso/xml/saml-2.0/saml2_attribute_statement.h>
#include <lasso/xml/saml-2.0/saml2_attribute_value.h>
#include <lasso/xml/saml-2.0/samlp2_idp_entry.h>
#include <lasso/xml/saml-2.0/samlp2_extensions.h>
#include <lasso/xml/saml-2.0/saml2_action.h>
#include <lasso/xml/saml-2.0/samlp2_status_response.h>
#include <lasso/xml/saml-2.0/samlp2_response.h>
#include <lasso/xml/saml-2.0/samlp2_artifact_response.h>
#include <lasso/xml/saml-2.0/samlp2_request_abstract.h>
#include <lasso/xml/saml-2.0/samlp2_assertion_id_request.h>
#include <lasso/xml/saml-2.0/samlp2_artifact_resolve.h>
#include <lasso/xml/saml-2.0/samlp2_name_id_mapping_request.h>
#include <lasso/xml/saml-2.0/samlp2_authn_request.h>
#include <lasso/xml/saml-2.0/samlp2_subject_query_abstract.h>
#include <lasso/xml/saml-2.0/samlp2_authz_decision_query.h>
#include <lasso/xml/saml-2.0/samlp2_attribute_query.h>
#include <lasso/xml/saml-2.0/saml2_audience_restriction.h>
#include <lasso/xml/saml-2.0/samlp2_logout_request.h>
#include <lasso/xml/saml-2.0/samlp2_authn_query.h>
#include <lasso/xml/saml-2.0/saml2_attribute.h>
#include <lasso/xml/saml-2.0/samlp2_terminate.h>
#include <lasso/xml/saml-2.0/samlp2_status_detail.h>
#include <lasso/xml/saml-2.0/saml2_authz_decision_statement.h>
#include <lasso/xml/saml-2.0/samlp2_name_id_mapping_response.h>
#include <lasso/xml/saml-2.0/saml2_encrypted_element.h>
#include <lasso/xml/saml-2.0/samlp2_manage_name_id_request.h>
#include <lasso/xml/saml-2.0/samlp2_scoping.h>
#include <lasso/xml/saml-2.0/saml2_subject.h>
%}
%include samlp2_name_id_policy.i
%include samlp2_requested_authn_context.i
%include saml2_assertion.i
%include samlp2_idp_list.i
%include saml2_key_info_confirmation_data.i
%include saml2_conditions.i
%include saml2_evidence.i
%include saml2_name_id.i
%include samlp2_status_code.i
%include samlp2_status.i
%include saml2_condition_abstract.i
%include saml2_one_time_use.i
%include saml2_advice.i
%include saml2_base_idabstract.i
%include saml2_authn_context.i
%include saml2_subject_locality.i
%include saml2_subject_confirmation_data.i
%include saml2_subject_confirmation.i
%include saml2_proxy_restriction.i
%include saml2_statement_abstract.i
%include saml2_authn_statement.i
%include saml2_attribute_statement.i
%include saml2_attribute_value.i
%include samlp2_idp_entry.i
%include samlp2_extensions.i
%include saml2_action.i
%include samlp2_status_response.i
%include samlp2_response.i
%include samlp2_artifact_response.i
%include samlp2_request_abstract.i
%include samlp2_assertion_id_request.i
%include samlp2_artifact_resolve.i
%include samlp2_name_id_mapping_request.i
%include samlp2_authn_request.i
%include samlp2_subject_query_abstract.i
%include samlp2_authz_decision_query.i
%include samlp2_attribute_query.i
%include saml2_audience_restriction.i
%include samlp2_logout_request.i
%include samlp2_authn_query.i
%include saml2_attribute.i
%include samlp2_terminate.i
%include samlp2_status_detail.i
%include saml2_authz_decision_statement.i
%include samlp2_name_id_mapping_response.i
%include saml2_encrypted_element.i
%include samlp2_manage_name_id_request.i
%include samlp2_scoping.i
%include saml2_subject.i
